@@ -23,8 +23,8 @@ import (
 	"errors"
 	"strings"
 
-	"git.zabbix.com/ap/plugin-support/zbxerr"
 	"github.com/jackc/pgx/v4"
+	"golang.zabbix.com/sdk/zbxerr"
 )
 
 // customQueryHandler executes custom user queries from *.sql files.
